@@ -6,9 +6,11 @@ from __future__ import unicode_literals
 import argparse
 import pipes
 import sys
+from typing import Optional
+from typing import Sequence
 
 
-def check_has_shebang(path):
+def check_has_shebang(path):  # type: (str) -> int
     with open(path, 'rb') as f:
         first_bytes = f.read(2)
 
@@ -16,7 +18,8 @@ def check_has_shebang(path):
         print(
             '{path}: marked executable but has no (or invalid) shebang!\n'
             "  If it isn't supposed to be executable, try: chmod -x {quoted}\n"
-            '  If it is supposed to be executable, double-check its shebang.'.format(
+            '  If it is supposed to be executable, double-check its shebang.'
+            .format(
                 path=path,
                 quoted=pipes.quote(path),
             ),
@@ -27,7 +30,7 @@ def check_has_shebang(path):
         return 0
 
 
-def main(argv=None):
+def main(argv=None):  # type: (Optional[Sequence[str]]) -> int
     parser = argparse.ArgumentParser(description=__doc__)
     parser.add_argument('filenames', nargs='*')
     args = parser.parse_args(argv)
@@ -38,3 +41,7 @@ def main(argv=None):
         retv |= check_has_shebang(filename)
 
     return retv
+
+
+if __name__ == '__main__':
+    exit(main())
